#
# spec file for package ghc-adler32
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name adler32
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.2.0
Release:        6.2
Summary:        An implementation of Adler-32, supporting rolling checksum operation
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  zlib-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
This package provides an implementation of the Adler-32 checksum algorithm.
It supports a rolling checksum mode, i.e. the checksum of a sliding window of
the input message can be computed efficiently. It also supports compounding,
i.e. the checksum of the concatenation of two messages can be efficiently
computed from the checksums of the two parts.

By default, the highly optimized implementation of Adler-32 from 'zlib' will be
used. This can be disabled, in which case a pure haskell implementation will be
used instead. On my system, the haskell version is 2 to 3 times slower.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       zlib-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Thu Apr 12 2018 psimons@suse.com
- Update adler32 to version 0.1.2.0.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.1.1.0 revision 1.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.1.1.0 revision 0 with cabal2obs.
